# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.0.0-beta.2

import datetime
import sys
import types
import typing
import uuid as _uuid
from builtins import property as _property

import winrt._winrt
import winrt.system
import winrt.windows.foundation

from winrt.windows.phone.media.devices import AudioRoutingEndpoint, AvailableAudioRoutingEndpoints

Self = typing.TypeVar('Self')

@typing.final
class AudioRoutingManager_Static(type):
    def get_default(cls) -> typing.Optional[AudioRoutingManager]: ...

@typing.final
class AudioRoutingManager(winrt.system.Object, metaclass=AudioRoutingManager_Static):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> AudioRoutingManager: ...
    def get_audio_endpoint(self) -> AudioRoutingEndpoint: ...
    def set_audio_endpoint(self, endpoint: AudioRoutingEndpoint, /) -> None: ...
    def add_audio_endpoint_changed(self, endpoint_change_handler: winrt.windows.foundation.TypedEventHandler[AudioRoutingManager, winrt.system.Object], /) -> winrt.windows.foundation.EventRegistrationToken: ...
    def remove_audio_endpoint_changed(self, token: winrt.windows.foundation.EventRegistrationToken, /) -> None: ...
    @_property
    def available_audio_endpoints(self) -> AvailableAudioRoutingEndpoints: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.0.0-beta.2

import enum

import winrt.system
from winrt import _winrt_windows_phone_media_devices

__all__ = [
    "AudioRoutingEndpoint",
    "AvailableAudioRoutingEndpoints",
    "AudioRoutingManager",
]

class AudioRoutingEndpoint(enum.IntEnum):
    DEFAULT = 0
    EARPIECE = 1
    SPEAKERPHONE = 2
    BLUETOOTH = 3
    WIRED_HEADSET = 4
    WIRED_HEADSET_SPEAKER_ONLY = 5
    BLUETOOTH_WITH_NOISE_AND_ECHO_CANCELLATION = 6
    BLUETOOTH_PREFERRED = 7

class AvailableAudioRoutingEndpoints(enum.IntFlag):
    NONE = 0
    EARPIECE = 0x1
    SPEAKERPHONE = 0x2
    BLUETOOTH = 0x4

AudioRoutingManager = _winrt_windows_phone_media_devices.AudioRoutingManager
